@@ -13,13 +13,13 @@ class GameConsts:
     # level mods from akhmorning
 
     # Key is the version. This is interpreted as stats at max-level for now.
-    __LEVEL_DIVS = {"6.55": 1900, "7.0": 2780, "test": 1900}
-    __LEVEL_MAINS = {"6.55": 390, "7.0": 440, "test": 390}
-    __LEVEL_SUBS = {"6.55": 400, "7.0": 420, "test": 400}
-    __FAP_CONSTS = {"6.55": 195, "7.0": 237, "test": 195}
-    __FAP_TANK_CONSTS = {"6.55": 156, "7.0": 190, "test": 156}
-    __TEN_CONSTS = {"6.55": 100, "7.0": 112, "test": 100}
-    __DH_CONSTS = {"6.55": 550, "7.0": 550, "test": 550}
+    __LEVEL_DIVS = {"6.55": 1900, "7.0": 2780, "7.01": 2780, "test": 1900}
+    __LEVEL_MAINS = {"6.55": 390, "7.0": 440, "7.01": 440, "test": 390}
+    __LEVEL_SUBS = {"6.55": 400, "7.0": 420, "7.01": 420, "test": 400}
+    __FAP_CONSTS = {"6.55": 195, "7.0": 237, "7.01": 237, "test": 195}
+    __FAP_TANK_CONSTS = {"6.55": 156, "7.0": 190, "7.01": 190, "test": 156}
+    __TEN_CONSTS = {"6.55": 100, "7.0": 112, "7.01": 112, "test": 100}
+    __DH_CONSTS = {"6.55": 550, "7.0": 550, "7.01": 550, "test": 550}
     
     # __LEVEL_DIVS = {"6.55": 1900, "7.0": 1900, "test": 1900}
     # __LEVEL_MAINS = {"6.55": 390, "7.0": 390, "test": 390}
@@ -29,16 +29,17 @@ class GameConsts:
     # __TEN_CONSTS = {"6.55": 100, "7.0": 100, "test": 100}
     # __DH_CONSTS = {"6.55": 550, "7.0": 550, "test": 550}
     
-    __SPEED_CONSTS = {"6.55": 130, "7.0": 130, "test": 130}
+    __SPEED_CONSTS = {"6.55": 130, "7.0": 130, "7.01": 130, "test": 130}
     __CRIT_CONSTS = {
         "6.55": (200, 50, 400),
         "7.0": (200, 50, 400),
+        "7.01": (200, 50, 400),
         "test": (200, 50, 400),
     }
 
-    __DH_CONSTS = {"6.55": 550, "7.0": 550, "test": 550}
+    __DH_CONSTS = {"6.55": 550, "7.0": 550, "7.01": 550, "test": 550}
 
-    __DET_CONSTS = {"6.55": 140, "7.0": 140, "test": 140}
+    __DET_CONSTS = {"6.55": 140, "7.0": 140, "7.01": 140, "test": 140}
 
     
 
@@ -152,3 +153,33 @@ class GameConsts:
         "Bard": "BRD",
         "Machinist": "MCH",
     }
+    
+    JOB_3_CODE_TO_ROLE = {
+        "WAR": "Tank",
+        "GNB": "Tank",
+        "PLD": "Tank",
+        "DRK": "Tank",
+        #
+        "WHM": "Healer",
+        "AST": "Healer",
+        "SGE": "Healer",
+        "SCH": "Healer",
+        #
+        "BRD": "Ranged",
+        "DNC": "Ranged",
+        "MCH": "Ranged",
+        #
+        "SMN": "Caster",
+        "RDM": "Caster",
+        "BLM": "Caster",
+        "PCT": "Caster",
+        #
+        "MNK": "Melee",
+        "DRG": "Melee",
+        "SAM": "Melee",
+        "RPR": "Melee",
+        "NIN": "Melee",
+        "VPR": "Melee",
+    }
+        
+        
