@@ -124,6 +124,7 @@ def add_ast_skills(skill_library):
                 base_cast_time=1500, animation_lock=100, application_delay=1160
             ),
             damage_spec=DamageSpec(potency=130),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
@@ -133,7 +134,9 @@ def add_ast_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=100, application_delay=620
             ),
-            damage_spec=DamageSpec(potency=250),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=250)},
+            has_aoe=True,
+            aoe_dropoff= 0.4
         )
     )
     skill_library.add_skill(
@@ -144,6 +147,7 @@ def add_ast_skills(skill_library):
                 base_cast_time=0, animation_lock=650, application_delay=620
             ),
             damage_spec=DamageSpec(potency=250),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
@@ -300,6 +304,7 @@ def add_ast_skills(skill_library):
                 skill_allowlist=("Stellar Explosion (pet)",),
             ),
             follow_up_skills=(stellar_detonation_follow_up2,),
+            has_aoe=True
         )
     )
 
@@ -318,6 +323,7 @@ def add_ast_skills(skill_library):
                 skill_allowlist=("Stellar Explosion (pet)", "Giant Dominance"),
             ),
             follow_up_skills=(giant_dom_follow_up, stellar_detonation_follow_up),
+            has_aoe=True
         )
     )
 
@@ -328,6 +334,7 @@ def add_ast_skills(skill_library):
             status_effect_denylist=("Dragon Sight",),
             timing_spec=TimingSpec(base_cast_time=0, application_delay=0),
             follow_up_skills=(stellar_detonation_instant,),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
@@ -340,6 +347,7 @@ def add_ast_skills(skill_library):
                 giant_dom_follow_up,
                 stellar_detonation_follow_up,
             ),
+            has_aoe=True
         )
     )
 
