@@ -97,6 +97,7 @@ def add_vpr_skills(skill_library):
                 ),
             ),
             delay_after_parent_application=delay_after_parent_application,
+            primary_target_only=True
         )
 
     skill_library.add_skill(
@@ -116,7 +117,7 @@ def add_vpr_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=200),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1160
             ),
         )
     )
@@ -127,6 +128,7 @@ def add_vpr_skills(skill_library):
             buff_spec=StatusEffectSpec(damage_mult=1.10, duration=40 * 1000),
         ),
         delay_after_parent_application=0,
+        primary_target_only=True
     )
     skill_library.add_skill(
         Skill(
@@ -134,7 +136,7 @@ def add_vpr_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=260),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=890
             ),
             follow_up_skills=(hunters_instinct_follow_up,),
         )
@@ -147,6 +149,7 @@ def add_vpr_skills(skill_library):
             ),
         ),
         delay_after_parent_application=0,
+        primary_target_only=True
     )
     skill_library.add_skill(
         Skill(
@@ -154,7 +157,7 @@ def add_vpr_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=140),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1290
             ),
             follow_up_skills=(noxious_gnash_follow_up,),
         )
@@ -165,7 +168,7 @@ def add_vpr_skills(skill_library):
             name="Writhing Snap",
             is_GCD=True,
             damage_spec=DamageSpec(potency=200),
-            timing_spec=instant_timing_spec,
+            timing_spec=TimingSpec(base_cast_time=0, animation_lock=650, application_delay=490),
         )
     )
     swift_scaled_follow_up = FollowUp(
@@ -178,6 +181,7 @@ def add_vpr_skills(skill_library):
             ),
         ),
         delay_after_parent_application=0,
+        primary_target_only=True
     )
 
     skill_library.add_skill(
@@ -186,14 +190,22 @@ def add_vpr_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=260),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1160
             ),
             follow_up_skills=(swift_scaled_follow_up,),
         )
     )
 
     skill_library.add_skill(
-        Skill(name="Steel Maw", is_GCD=True, damage_spec=DamageSpec(potency=100))
+        Skill(
+            name="Steel Maw",
+            is_GCD=True,
+            timing_spec=TimingSpec(
+                base_cast_time=0, animation_lock=650, application_delay=1020
+            ),
+            damage_spec=DamageSpec(potency=100),
+            has_aoe=True,
+        )
     )
     hindstung_venom_follow_up = get_venom_follow_up(
         "Hindstung Venom",
@@ -226,7 +238,7 @@ def add_vpr_skills(skill_library):
                 ),
             },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=620 #application delay is a bit off due to venom timing
             ),
             follow_up_skills=(hindstung_venom_follow_up,),
         )
@@ -263,9 +275,9 @@ def add_vpr_skills(skill_library):
                 ),
             },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=620 #application delay is a bit off due to venom timing
             ),
-            follow_up_skills=(hindsbane_venom_follow_up,),
+            follow_up_skills=(hindsbane_venom_follow_up,), #application delay is a bit off due to venom timing
         )
     )
 
@@ -300,7 +312,7 @@ def add_vpr_skills(skill_library):
                 ),
             },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=620 #application delay is a bit off due to venom timing
             ),
             follow_up_skills=(flanksbane_venom_follow_up,),
         )
@@ -351,6 +363,7 @@ def add_vpr_skills(skill_library):
                 base_cast_time=0, animation_lock=650, application_delay=620
             ),
             follow_up_skills=(noxious_gnash_follow_up,),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
@@ -359,9 +372,10 @@ def add_vpr_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=120),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1070
             ),
             follow_up_skills=(hunters_instinct_follow_up,),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
@@ -370,9 +384,10 @@ def add_vpr_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=120),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1380
             ),
             follow_up_skills=(swift_scaled_follow_up,),
+            has_aoe=True
         )
     )
 
@@ -397,9 +412,10 @@ def add_vpr_skills(skill_library):
                 "Grimhunter's Venom": DamageSpec(potency=160),
             },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=620 #application delay is a bit off due to venom timing
             ),
             follow_up_skills=(grimskins_venom_follow_up,),
+            has_aoe=True
         )
     )
     grimhunters_venom_follow_up = get_venom_follow_up(
@@ -423,9 +439,10 @@ def add_vpr_skills(skill_library):
                 "Grimskin's Venom": DamageSpec(potency=160),
             },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=620 #application delay is a bit off due to venom timing
             ),
             follow_up_skills=(grimhunters_venom_follow_up,),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
@@ -434,7 +451,7 @@ def add_vpr_skills(skill_library):
             is_GCD=False,
             damage_spec=DamageSpec(potency=250),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1700
             ),
         )
     )
@@ -444,8 +461,9 @@ def add_vpr_skills(skill_library):
             is_GCD=False,
             damage_spec=DamageSpec(potency=100),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1160
             ),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
@@ -456,7 +474,7 @@ def add_vpr_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=580,
                 gcd_base_recast_time=3000,
             ),
             follow_up_skills=(noxious_gnash_follow_up,),
@@ -478,7 +496,7 @@ def add_vpr_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=620, #application delay is a bit off due to venom timing
                 gcd_base_recast_time=3000,
             ),
             follow_up_skills=(hunters_instinct_follow_up, hunters_venom_follow_up),
@@ -500,7 +518,7 @@ def add_vpr_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=620, #application delay is a bit off due to venom timing
                 gcd_base_recast_time=3000,
             ),
             follow_up_skills=(swift_scaled_follow_up, swiftskins_venom_follow_up),
@@ -512,10 +530,11 @@ def add_vpr_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=200),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=760
             ),
             follow_up_skills=(noxious_gnash_follow_up,),
-        )
+            has_aoe=True
+        )        
     )
 
     fellhunters_venom_follow_up = get_venom_follow_up(
@@ -530,10 +549,11 @@ def add_vpr_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=490,
                 gcd_base_recast_time=3000,
             ),
             follow_up_skills=(hunters_instinct_follow_up, fellhunters_venom_follow_up),
+            has_aoe=True
         )
     )
 
@@ -547,9 +567,10 @@ def add_vpr_skills(skill_library):
             combo_spec=(ComboSpec(combo_group=3),),
             damage_spec=DamageSpec(potency=250),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=790
             ),
-            follow_up_skills=(swift_scaled_follow_up, fellskins_venom_follow_up),
+            follow_up_skills=(swift_scaled_follow_up, fellskins_venom_follow_up), #application delay is a bit off due to venom timing
+            has_aoe=True
         )
     )
     skill_library.add_skill(
@@ -580,7 +601,7 @@ def add_vpr_skills(skill_library):
                 "Swiftskin's Venom": DamageSpec(potency=150),
             },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=670
             ),
             follow_up_skills={
                 SimConsts.DEFAULT_CONDITION: (hunters_venom_follow_up,),
@@ -598,12 +619,13 @@ def add_vpr_skills(skill_library):
                 "Fellskin's Venom": DamageSpec(potency=80),
             },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=670
             ),
             follow_up_skills={
                 SimConsts.DEFAULT_CONDITION: (fellskins_venom_follow_up,),
                 "No Combo": tuple(),
             },
+            has_aoe=True
         )
     )
     skill_library.add_skill(
@@ -622,24 +644,35 @@ def add_vpr_skills(skill_library):
                 SimConsts.DEFAULT_CONDITION: (fellhunters_venom_follow_up,),
                 "No Combo": tuple(),
             },
+            has_aoe=True
         )
     )
 
     poised_for_twinfang_follow_up = get_venom_follow_up(
         "Poised for Twinfang", ("Uncoiled Twinfang",), 60 * 1000
     )
+    uncoiled_fury_follow_up = FollowUp(
+        Skill(
+            name="Uncoiled Fury", damage_spec=DamageSpec(potency=600), aoe_dropoff=0.5
+        ),
+        delay_after_parent_application=800,
+        primary_target_only=False,
+    )
     skill_library.add_skill(
         Skill(
             name="Uncoiled Fury",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=600),
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=0,
                 gcd_base_recast_time=3500,
             ),
-            follow_up_skills=(poised_for_twinfang_follow_up,),
+            follow_up_skills=(
+                uncoiled_fury_follow_up,
+                poised_for_twinfang_follow_up,
+            ),
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -654,6 +687,8 @@ def add_vpr_skills(skill_library):
                 application_delay=620,
                 gcd_base_recast_time=2200,
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6
         )
     )
     skill_library.add_skill(
@@ -668,9 +703,11 @@ def add_vpr_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=1700,
                 gcd_base_recast_time=2000,
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6
         )
     )
     skill_library.add_skill(
@@ -685,9 +722,11 @@ def add_vpr_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=1470,
                 gcd_base_recast_time=2000,
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6
         )
     )
     skill_library.add_skill(
@@ -704,9 +743,11 @@ def add_vpr_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=1470,
                 gcd_base_recast_time=2000,
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6
         )
     )
     skill_library.add_skill(
@@ -721,9 +762,11 @@ def add_vpr_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=1470,
                 gcd_base_recast_time=2000,
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6
         )
     )
     poised_for_twinblood_follow_up = get_venom_follow_up(
@@ -740,9 +783,11 @@ def add_vpr_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=620, #application delay is a bit off due to venom timing
             ),
             follow_up_skills=(poised_for_twinblood_follow_up,),
+            has_aoe=True,
+            aoe_dropoff=0.5
         )
     )
     skill_library.add_skill(
@@ -754,8 +799,10 @@ def add_vpr_skills(skill_library):
                 "Poised for Twinblood": DamageSpec(potency=150),
             },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=980
             ),
+            has_aoe=True,
+            aoe_dropoff=0.5
         )
     )
     skill_library.add_skill(
@@ -766,9 +813,11 @@ def add_vpr_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=2330,
                 gcd_base_recast_time=3000,
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6
         )
     )
 
@@ -778,8 +827,10 @@ def add_vpr_skills(skill_library):
             is_GCD=False,
             damage_spec=DamageSpec(potency=250),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1290
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6
         )
     )
     skill_library.add_skill(
@@ -788,8 +839,10 @@ def add_vpr_skills(skill_library):
             is_GCD=False,
             damage_spec=DamageSpec(potency=250),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1070
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6
         )
     )
     skill_library.add_skill(
@@ -798,8 +851,10 @@ def add_vpr_skills(skill_library):
             is_GCD=False,
             damage_spec=DamageSpec(potency=250),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1210
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6
         )
     )
     skill_library.add_skill(
@@ -808,8 +863,10 @@ def add_vpr_skills(skill_library):
             is_GCD=False,
             damage_spec=DamageSpec(potency=250),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1070
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6
         )
     )
     # These skills do not damage, but grants resources/affects future skills.
