@@ -1,5 +1,6 @@
 import ama_xiv_combat_sim.simulator.game_data.patch_655.class_skills.caster as patch655
 import ama_xiv_combat_sim.simulator.game_data.patch_70.class_skills.caster as patch70
+import ama_xiv_combat_sim.simulator.game_data.patch_701.class_skills.caster as patch701
 
 def add_caster_skills_to_skill_library(skill_library, version="6.55"):
     match version:
@@ -8,8 +9,11 @@ def add_caster_skills_to_skill_library(skill_library, version="6.55"):
         case "7.0":
             patch_use = patch70
             patch_use.add_pct_skills(skill_library)
+        case "7.01":
+            patch_use = patch701
+            patch_use.add_pct_skills(skill_library)
         case _:
-            raise RuntimeError("Bad version: {}".format(version))
+            raise RuntimeError(f"Bad version: {version}")
     skill_library = patch_use.add_blm_skills(skill_library)
     skill_library = patch_use.add_rdm_skills(skill_library)
     skill_library = patch_use.add_smn_skills(skill_library)
