@@ -1,6 +1,6 @@
 from dataclasses import dataclass
 
-from simulator.calcs.forced_crit_or_dh import ForcedCritOrDH
+from ama_xiv_combat_sim.simulator.calcs.forced_crit_or_dh import ForcedCritOrDH
 
 @dataclass(frozen=True)
 class StatusEffects():
